@@ -1,6 +1,6 @@
 /*
   Simple DirectMedia Layer
-  Copyright (C) 1997-2022 Sam Lantinga <slouken@libsdl.org>
+  Copyright (C) 1997-2025 Sam Lantinga <slouken@libsdl.org>
 
   This software is provided 'as-is', without any express or implied
   warranty.  In no event will the authors be held liable for any damages
@@ -65,7 +65,7 @@ static SDL_Windows_Sensor *SDL_sensors;
 static int ConnectSensor(ISensor *sensor);
 static int DisconnectSensor(ISensor *sensor);
 
-static HRESULT STDMETHODCALLTYPE ISensorManagerEventsVtbl_QueryInterface(ISensorManagerEvents * This, REFIID riid, void **ppvObject)
+static HRESULT STDMETHODCALLTYPE ISensorManagerEventsVtbl_QueryInterface(ISensorManagerEvents *This, REFIID riid, void **ppvObject)
 {
     if (!ppvObject) {
         return E_INVALIDARG;
@@ -79,17 +79,17 @@ static HRESULT STDMETHODCALLTYPE ISensorManagerEventsVtbl_QueryInterface(ISensor
     return E_NOINTERFACE;
 }
 
-static ULONG STDMETHODCALLTYPE ISensorManagerEventsVtbl_AddRef(ISensorManagerEvents * This)
+static ULONG STDMETHODCALLTYPE ISensorManagerEventsVtbl_AddRef(ISensorManagerEvents *This)
 {
     return 1;
 }
 
-static ULONG STDMETHODCALLTYPE ISensorManagerEventsVtbl_Release(ISensorManagerEvents * This)
+static ULONG STDMETHODCALLTYPE ISensorManagerEventsVtbl_Release(ISensorManagerEvents *This)
 {
     return 1;
 }
 
-static HRESULT STDMETHODCALLTYPE ISensorManagerEventsVtbl_OnSensorEnter(ISensorManagerEvents * This, ISensor *pSensor, SensorState state)
+static HRESULT STDMETHODCALLTYPE ISensorManagerEventsVtbl_OnSensorEnter(ISensorManagerEvents *This, ISensor *pSensor, SensorState state)
 {
     ConnectSensor(pSensor);
     return S_OK;
@@ -105,7 +105,7 @@ static ISensorManagerEvents sensor_manager_events = {
     &sensor_manager_events_vtbl
 };
 
-static HRESULT STDMETHODCALLTYPE ISensorEventsVtbl_QueryInterface(ISensorEvents * This, REFIID riid, void **ppvObject)
+static HRESULT STDMETHODCALLTYPE ISensorEventsVtbl_QueryInterface(ISensorEvents *This, REFIID riid, void **ppvObject)
 {
     if (!ppvObject) {
         return E_INVALIDARG;
@@ -119,17 +119,17 @@ static HRESULT STDMETHODCALLTYPE ISensorEventsVtbl_QueryInterface(ISensorEvents
     return E_NOINTERFACE;
 }
 
-static ULONG STDMETHODCALLTYPE ISensorEventsVtbl_AddRef(ISensorEvents * This)
+static ULONG STDMETHODCALLTYPE ISensorEventsVtbl_AddRef(ISensorEvents *This)
 {
     return 1;
 }
 
-static ULONG STDMETHODCALLTYPE ISensorEventsVtbl_Release(ISensorEvents * This)
+static ULONG STDMETHODCALLTYPE ISensorEventsVtbl_Release(ISensorEvents *This)
 {
     return 1;
 }
 
-static HRESULT STDMETHODCALLTYPE ISensorEventsVtbl_OnStateChanged(ISensorEvents * This, ISensor *pSensor, SensorState state)
+static HRESULT STDMETHODCALLTYPE ISensorEventsVtbl_OnStateChanged(ISensorEvents *This, ISensor *pSensor, SensorState state)
 {
 #ifdef DEBUG_SENSORS
     int i;
@@ -145,7 +145,7 @@ static HRESULT STDMETHODCALLTYPE ISensorEventsVtbl_OnStateChanged(ISensorEvents
     return S_OK;
 }
 
-static HRESULT STDMETHODCALLTYPE ISensorEventsVtbl_OnDataUpdated(ISensorEvents * This, ISensor *pSensor, ISensorDataReport *pNewData)
+static HRESULT STDMETHODCALLTYPE ISensorEventsVtbl_OnDataUpdated(ISensorEvents *This, ISensor *pSensor, ISensorDataReport *pNewData)
 {
     int i;
 
@@ -171,7 +171,7 @@ static HRESULT STDMETHODCALLTYPE ISensorEventsVtbl_OnDataUpdated(ISensorEvents *
                         values[0] = (float)valueX.dblVal * SDL_STANDARD_GRAVITY;
                         values[1] = (float)valueY.dblVal * SDL_STANDARD_GRAVITY;
                         values[2] = (float)valueZ.dblVal * SDL_STANDARD_GRAVITY;
-                        SDL_PrivateSensorUpdate(SDL_sensors[i].sensor_opened, values, 3);
+                        SDL_PrivateSensorUpdate(SDL_sensors[i].sensor_opened, 0, values, 3);
                     }
                     break;
                 case SDL_SENSOR_GYRO:
@@ -186,7 +186,7 @@ static HRESULT STDMETHODCALLTYPE ISensorEventsVtbl_OnDataUpdated(ISensorEvents *
                         values[0] = (float)valueX.dblVal * DEGREES_TO_RADIANS;
                         values[1] = (float)valueY.dblVal * DEGREES_TO_RADIANS;
                         values[2] = (float)valueZ.dblVal * DEGREES_TO_RADIANS;
-                        SDL_PrivateSensorUpdate(SDL_sensors[i].sensor_opened, values, 3);
+                        SDL_PrivateSensorUpdate(SDL_sensors[i].sensor_opened, 0, values, 3);
                     }
                     break;
                 default:
@@ -202,7 +202,7 @@ static HRESULT STDMETHODCALLTYPE ISensorEventsVtbl_OnDataUpdated(ISensorEvents *
     return S_OK;
 }
 
-static HRESULT STDMETHODCALLTYPE ISensorEventsVtbl_OnEvent(ISensorEvents * This, ISensor *pSensor, REFGUID eventID, IPortableDeviceValues *pEventData)
+static HRESULT STDMETHODCALLTYPE ISensorEventsVtbl_OnEvent(ISensorEvents *This, ISensor *pSensor, REFGUID eventID, IPortableDeviceValues *pEventData)
 {
 #ifdef DEBUG_SENSORS
     int i;
@@ -218,7 +218,7 @@ static HRESULT STDMETHODCALLTYPE ISensorEventsVtbl_OnEvent(ISensorEvents * This,
     return S_OK;
 }
 
-static HRESULT STDMETHODCALLTYPE ISensorEventsVtbl_OnLeave(ISensorEvents * This, REFSENSOR_ID ID)
+static HRESULT STDMETHODCALLTYPE ISensorEventsVtbl_OnLeave(ISensorEvents *This, REFSENSOR_ID ID)
 {
     int i;
 
@@ -292,7 +292,7 @@ static int ConnectSensor(ISensor *sensor)
 
     SDL_LockSensors();
     new_sensors = (SDL_Windows_Sensor *)SDL_realloc(SDL_sensors, (SDL_num_sensors + 1) * sizeof(SDL_Windows_Sensor));
-    if (new_sensors == NULL) {
+    if (!new_sensors) {
         SDL_UnlockSensors();
         SDL_free(name);
         return SDL_OutOfMemory();
@@ -343,8 +343,7 @@ static int DisconnectSensor(ISensor *sensor)
     return 0;
 }
 
-static int
-SDL_WINDOWS_SensorInit(void)
+static int SDL_WINDOWS_SensorInit(void)
 {
     HRESULT hr;
     ISensorCollection *sensor_collection = NULL;
@@ -353,7 +352,7 @@ SDL_WINDOWS_SensorInit(void)
         SDL_windowscoinit = SDL_TRUE;
     }
 
-    hr = CoCreateInstance(&SDL_CLSID_SensorManager, NULL, CLSCTX_INPROC_SERVER, &SDL_IID_SensorManager, (LPVOID *) &SDL_sensor_manager);
+    hr = CoCreateInstance(&SDL_CLSID_SensorManager, NULL, CLSCTX_INPROC_SERVER, &SDL_IID_SensorManager, (LPVOID *)&SDL_sensor_manager);
     if (FAILED(hr)) {
         /* If we can't create a sensor manager (i.e. on Wine), we won't have any sensors, but don't fail the init */
         return 0; /* WIN_SetErrorFromHRESULT("Couldn't create the sensor manager", hr); */
@@ -392,55 +391,46 @@ SDL_WINDOWS_SensorInit(void)
     return 0;
 }
 
-static int
-SDL_WINDOWS_SensorGetCount(void)
+static int SDL_WINDOWS_SensorGetCount(void)
 {
     return SDL_num_sensors;
 }
 
-static void
-SDL_WINDOWS_SensorDetect(void)
+static void SDL_WINDOWS_SensorDetect(void)
 {
 }
 
-static const char *
-SDL_WINDOWS_SensorGetDeviceName(int device_index)
+static const char *SDL_WINDOWS_SensorGetDeviceName(int device_index)
 {
     return SDL_sensors[device_index].name;
 }
 
-static SDL_SensorType
-SDL_WINDOWS_SensorGetDeviceType(int device_index)
+static SDL_SensorType SDL_WINDOWS_SensorGetDeviceType(int device_index)
 {
     return SDL_sensors[device_index].type;
 }
 
-static int
-SDL_WINDOWS_SensorGetDeviceNonPortableType(int device_index)
+static int SDL_WINDOWS_SensorGetDeviceNonPortableType(int device_index)
 {
     return -1;
 }
 
-static SDL_SensorID
-SDL_WINDOWS_SensorGetDeviceInstanceID(int device_index)
+static SDL_SensorID SDL_WINDOWS_SensorGetDeviceInstanceID(int device_index)
 {
     return SDL_sensors[device_index].id;
 }
 
-static int
-SDL_WINDOWS_SensorOpen(SDL_Sensor *sensor, int device_index)
+static int SDL_WINDOWS_SensorOpen(SDL_Sensor *sensor, int device_index)
 {
     SDL_sensors[device_index].sensor_opened = sensor;
     return 0;
 }
 
-static void
-SDL_WINDOWS_SensorUpdate(SDL_Sensor *sensor)
+static void SDL_WINDOWS_SensorUpdate(SDL_Sensor *sensor)
 {
 }
 
-static void
-SDL_WINDOWS_SensorClose(SDL_Sensor *sensor)
+static void SDL_WINDOWS_SensorClose(SDL_Sensor *sensor)
 {
     int i;
 
@@ -452,8 +442,7 @@ SDL_WINDOWS_SensorClose(SDL_Sensor *sensor)
     }
 }
 
-static void
-SDL_WINDOWS_SensorQuit(void)
+static void SDL_WINDOWS_SensorQuit(void)
 {
     while (SDL_num_sensors > 0) {
         DisconnectSensor(SDL_sensors[0].sensor);
@@ -470,8 +459,7 @@ SDL_WINDOWS_SensorQuit(void)
     }
 }
 
-SDL_SensorDriver SDL_WINDOWS_SensorDriver =
-{
+SDL_SensorDriver SDL_WINDOWS_SensorDriver = {
     SDL_WINDOWS_SensorInit,
     SDL_WINDOWS_SensorGetCount,
     SDL_WINDOWS_SensorDetect,
