@@ -1,6 +1,6 @@
 /*
   Simple DirectMedia Layer
-  Copyright (C) 1997-2023 Sam Lantinga <slouken@libsdl.org>
+  Copyright (C) 1997-2025 Sam Lantinga <slouken@libsdl.org>
 
   This software is provided 'as-is', without any express or implied
   warranty.  In no event will the authors be held liable for any damages
@@ -20,7 +20,7 @@
 */
 #include "../../SDL_internal.h"
 
-#if SDL_VIDEO_DRIVER_DIRECTFB
+#ifdef SDL_VIDEO_DRIVER_DIRECTFB
 
 /* Handle the event stream, converting DirectFB input events into SDL events */
 
@@ -308,7 +308,7 @@ static void ProcessInputEvent(_THIS, DFBInputEvent * ievt)
 
     if (!devdata->use_linux_input) {
         if (ievt->type == DIET_AXISMOTION) {
-            if ((grabbed_window != NULL) && (ievt->flags & DIEF_AXISREL)) {
+            if ((grabbed_window) && (ievt->flags & DIEF_AXISREL)) {
                 if (ievt->axis == DIAI_X)
                     SDL_SendMouseMotion_ex(grabbed_window, ievt->device_id, 1,
                                         ievt->axisrel, 0, 0);
@@ -405,7 +405,7 @@ void DirectFB_PumpEventsWindow(_THIS)
     DFBInputEvent ievt;
     SDL_Window *w;
 
-    for (w = devdata->firstwin; w != NULL; w = w->next) {
+    for (w = devdata->firstwin; w; w = w->next) {
         SDL_DFB_WINDOWDATA(w);
         DFBWindowEvent evt;
 
