@@ -1,6 +1,6 @@
 /*
   Simple DirectMedia Layer
-  Copyright (C) 1997-2021 Sam Lantinga <slouken@libsdl.org>
+  Copyright (C) 1997-2025 Sam Lantinga <slouken@libsdl.org>
 
   This software is provided 'as-is', without any express or implied
   warranty.  In no event will the authors be held liable for any damages
@@ -20,7 +20,7 @@
 */
 #include "../../SDL_internal.h"
 
-#if SDL_VIDEO_DRIVER_DUMMY
+#ifdef SDL_VIDEO_DRIVER_DUMMY
 
 /* Being a null driver, there's no event stream. We just define stubs for
    most of the API. */
@@ -30,8 +30,7 @@
 #include "SDL_nullvideo.h"
 #include "SDL_nullevents_c.h"
 
-void
-DUMMY_PumpEvents(_THIS)
+void DUMMY_PumpEvents(_THIS)
 {
     /* do nothing. */
 }
